==> okteta-0.26.1.tar.xz: okteta-0.26.1/kasten/controllers/view/poddecoder/podtableview.hpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2006-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KASTEN_PODTABLEVIEW_HPP
#define KASTEN_PODTABLEVIEW_HPP

// lib
#include "abstractdifferentsizedialog.hpp"
// Qt
#include <QWidget>

class KComboBox;
class QTreeView;
class QCheckBox;
class QModelIndex;

namespace Kasten {

class PODTableModel;
class PODDecoderTool;

class PODTableView : public QWidget
                   , public AbstractDifferentSizeDialog
{
    Q_OBJECT

public:
    explicit PODTableView(PODDecoderTool* tool, QWidget* parent = nullptr);
    ~PODTableView() override;

public:
    PODDecoderTool* tool() const;

public: // QObject API
    bool eventFilter(QObject* object, QEvent* event) override;

public: // AbstractDifferentSizeDialog API
    Answer query(int newValueSize, int oldValueSize, int sizeLeft) override;

private Q_SLOTS:
    void onCurrentRowChanged(const QModelIndex& current, const QModelIndex& previous);

private:
    PODDecoderTool* mTool;

    PODTableModel* mPODTableModel;

    QTreeView* mPODTableView;
    KComboBox* mByteOrderSelection;
    QCheckBox* mUnsignedAsHexCheck;

    QWidget* mPODTableViewFocusChild = nullptr;
};

inline PODDecoderTool* PODTableView::tool() const { return mTool; }

}

#endif

==> okteta_0.26.21.orig.tar.xz: okteta-0.26.21/kasten/controllers/view/poddecoder/podtableview.hpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    SPDX-FileCopyrightText: 2006-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef KASTEN_PODTABLEVIEW_HPP
#define KASTEN_PODTABLEVIEW_HPP

// lib
#include "abstractdifferentsizedialog.hpp"
// Qt
#include <QWidget>

class KComboBox;
class QTreeView;
class QCheckBox;
class QModelIndex;

namespace Kasten {

class PODDelegate;
class PODTableModel;
class PODDecoderTool;

class PODTableView : public QWidget
                   , public AbstractDifferentSizeDialog
{
    Q_OBJECT

public:
    explicit PODTableView(PODDecoderTool* tool, QWidget* parent = nullptr);
    ~PODTableView() override;

public:
    PODDecoderTool* tool() const;

public: // QObject API
    bool eventFilter(QObject* object, QEvent* event) override;

public: // AbstractDifferentSizeDialog API
    Answer query(int newValueSize, int oldValueSize, int sizeLeft) override;

private Q_SLOTS:
    void onCurrentRowChanged(const QModelIndex& current, const QModelIndex& previous);
    void onCustomContextMenuRequested(QPoint pos);
    void copyToClipboard();
    void selectBytesInView();

private:
    PODDecoderTool* mTool;

    PODTableModel* mPODTableModel;

    QTreeView* mPODTableView;
    PODDelegate* mPODDelegate;
    KComboBox* mByteOrderSelection;
    QCheckBox* mUnsignedAsHexCheck;

    QWidget* mPODTableViewFocusChild = nullptr;
};

inline PODDecoderTool* PODTableView::tool() const { return mTool; }

}

#endif
